Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/certbot/certbot.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorohemorange <ebportnoy@gmail.com>2020-07-02 03:07:41 +0300
committerGitHub <noreply@github.com>2020-07-02 03:07:41 +0300
commitcb3ff9ef18a6a2341192731e207674a5c4705ec4 (patch)
tree9cc1f7f082f548a8815111887f508a9fb42cb394 /tests
parentf743dbec3a04349533735a161b650f02844b2294 (diff)
Set up CentOS 8 test farm tests (#8122)
Fixes #7420. * Set up CentOS 8 test farm tests * Don't add to apache2_targets until 7273 is resolved * Start upgrade test from a version that works on centos 8 * remove when possible from targets
Diffstat (limited to 'tests')
-rw-r--r--tests/letstest/apache2_targets.yaml2
-rwxr-xr-xtests/letstest/scripts/test_leauto_upgrades.sh4
-rw-r--r--tests/letstest/targets.yaml7
3 files changed, 11 insertions, 2 deletions
diff --git a/tests/letstest/apache2_targets.yaml b/tests/letstest/apache2_targets.yaml
index 0f566dc65..d0a682bae 100644
--- a/tests/letstest/apache2_targets.yaml
+++ b/tests/letstest/apache2_targets.yaml
@@ -1,3 +1,5 @@
+# These images are located in us-east-1.
+
targets:
#-----------------------------------------------------------------------------
#Ubuntu
diff --git a/tests/letstest/targets.yaml b/tests/letstest/targets.yaml
index 98433837c..2cda2d6ef 100644
--- a/tests/letstest/targets.yaml
+++ b/tests/letstest/targets.yaml
@@ -1,3 +1,5 @@
+# These images are located in us-east-1.
+
targets:
#-----------------------------------------------------------------------------
#Ubuntu
@@ -85,3 +87,8 @@ targets:
runcmd:
- yum install -y epel-release
- iptables -F
+ - ami: ami-01ca03df4a6012157
+ name: centos8
+ type: centos
+ virt: hvm
+ user: centos
diff --git a/tests/letstest/scripts/test_leauto_upgrades.sh b/tests/letstest/scripts/test_leauto_upgrades.sh
index fc7632793..40b70c342 100755
--- a/tests/letstest/scripts/test_leauto_upgrades.sh
+++ b/tests/letstest/scripts/test_leauto_upgrades.sh
@@ -23,8 +23,8 @@ if command -v python && [ $(python -V 2>&1 | cut -d" " -f 2 | cut -d. -f1,2 | se
INITIAL_VERSION="0.20.0"
RUN_RHEL6_TESTS=1
else
- # 0.37.x is the oldest version of letsencrypt-auto that works on RHEL 8.
- INITIAL_VERSION="0.37.1"
+ # 0.39.0 is the oldest version of letsencrypt-auto that works on CentOS 8.
+ INITIAL_VERSION="0.39.0"
fi
git checkout -f "v$INITIAL_VERSION" letsencrypt-auto